@@ -5,6 +5,9 @@
 #' @param data \code{Numeric} vector of length two or data frame, 
 #' x-, y-coordinates to be converted.
 #' 
+#' @param from \code{Character} value, proj4 string of the input 
+#' reference system. 
+#' 
 #' @param to \code{Character} value, proj4 string of the output 
 #' reference system. 
 #' 
@@ -19,11 +22,13 @@
 #' ## create lat lon coordinates
 #' xy <- c(13, 55)
 #'
-#' ## define output coordinate system 
+#' ## define output coordinate systems 
+#' proj_in <- "+proj=longlat +datum=WGS84"
 #' proj_out <- "+proj=utm +zone=32 +datum=WGS84"
 #' 
 #' ## convert coordinate pair
 #' spatial_convert(data = xy, 
+#'                 from = proj_in,
 #'                 to = proj_out)
 #'                 
 #' ## define set of coordinates
@@ -32,11 +37,13 @@
 #'                  
 #' ## convert set of coordinates
 #' spatial_convert(data = xy, 
+#'                 from = proj_in,
 #'                 to = proj_out)
 #'                      
 #' @export spatial_convert
 spatial_convert <- function(
   data,
+  from,
   to
 ) {
   
@@ -56,6 +63,7 @@ spatial_convert <- function(
     if(length(data) != 2) {
       
       stop("Coordinate data must contain only 2 values, x and y!")
+      
     } else {
       
       ## convert vector to data frame
@@ -67,11 +75,14 @@ spatial_convert <- function(
     stop("Only data frames and vectors are supported as input data!")
   }
   
+  ## create SpatVector object
+  data <- terra::vect(x = data, crs = from)
+  
   ## project data set
-  data <- rgdal::project(data, to)
+  data <- terra::project(x = data, y = to)
   
   ## convert output to data frame
-  data <- as.data.frame(data)
+  data <- as.data.frame(terra::crds(x = data))
   
   ## return data frame
   return(data)
